<?php

class SubscriptionManagement {
	public static function init() {
		self::hooksInit();
	}

	public static function hooksInit() {
		wp_enqueue_style( 'subscription-management-is-css', plugin_dir_url( __FILE__ ) . 'css/subscription-management-is.css' );
		wp_enqueue_script( 'subscription-management-is-js', plugin_dir_url( __FILE__ ) . 'js/subscription-management-is.js' );
		//add_action( 'init', array('SubscriptionManagement', 'rewrites_init') );
		//add_filter('template_include', array('SubscriptionManagement', 'template_init'));
		add_shortcode( 'is_manage_subscriptions', [ 'SubscriptionManagement', 'manageSubscriptions' ] );
	}

	function manageSubscriptions( $atts ) {
		$appname    = get_option( 'subscription_isdk_app_name' );
		$apikey     = get_option( 'subscription_isdk_api_key' );
		$app        = new iSDK();
		$this_email = '';
		$output     = '';
		// if appname and apikey are properly defined in admin settings page
		if ( $appname && $apikey ) {

			// if the appname and apikey are valid and properly connect to InfusionSoft API account
			if ( $app->cfgCon( $appname, $apikey ) ) {

				// if the form is posted with a subscription update
				if ( $_SERVER['REQUEST_METHOD'] == 'POST' ) {
					if ( $_POST['formtype'] == 'subupdate' ) {
						self::saveSubscriptionPreferences( $app );
					}
				}
				// if email is passed from GET or POST
				if ( ! empty( $_REQUEST['email'] ) ) {
					if ( filter_var( $_REQUEST['email'], FILTER_VALIDATE_EMAIL ) ) {
						$this_email = sanitize_email( $_REQUEST['email'] );
					}
					// if current user is logged in, then show subscriptions based on that user's account information (email)
				} elseif ( is_user_logged_in() ) {
					global $current_user;
					$current_user = wp_get_current_user();
					$this_email   = $current_user->user_email;
					// if no email is available, request it
				} else {
					$output = <<<HTML
                  <div id="email_tracking_manage_subscriptions">
                    <p>Sorry - for some reason we couldn't automatically identify your email.
                      Please enter it here to manage your preferences.</p>
                    <form action="" method="post" id="sm_email_form">
                      <input type="hidden" name="formtype" value="emailupdate">
                      <input type="text" name="email" placeholder="Enter Your Email" id="email" size="200" />
                      <input type="submit" value="Manage Your Preferences" />
                    </form>
                  </div>
HTML;
				}
				// if an email has been obtained using a method from above
				if ( $this_email ) {

					$user_return_fields = [
						'Id',
						'Groups'
					];
					$user_current_tags  = $app->findByEmail( $this_email, $user_return_fields );
					if ( ! $user_current_tags ) {
						$con_data = [ 'Email' => $this_email ];
						$app->addCon( $con_data );
						$user_current_tags = $app->findByEmail( $this_email, $user_return_fields );
					}
					$output = <<<HTML
                  <div id="email_tracking_manage_subscriptions">
                    <form action="" method="post" id="sm_form">
                      <input type="hidden" name="formtype" value="subupdate">
HTML;
					$user_current_tags        = $app->findByEmail( $this_email, $user_return_fields );
					$user_current_tags        = explode( ",", $user_current_tags[0]['Groups'] );
					$checked_current_tag_cats = explode( ',', get_option( 'subscription_tag_categories' ) );
					$category_return_fields   = [ 'Id', 'CategoryName' ];
					$group_return_fields      = [ 'Id', 'GroupName' ];
					$num_checked              = 0;
					for ( $i = 0; $i < sizeof( $checked_current_tag_cats ); $i ++ ) {
						$category_query = [ 'Id' => $checked_current_tag_cats[ $i ] ];
						$category_info  = $app->dsQuery( 'ContactGroupCategory', 1000, 0, $category_query, $category_return_fields );
						$group_query    = [ 'GroupCategoryId' => $category_info[0]['Id'] ];
						$output         .= '<div class="sm_block">';
						$groups = $app->dsQuery( 'ContactGroup', 1000, 0, $group_query, $group_return_fields );
						for ( $j = 0; $j < sizeof( $groups ); $j ++ ) {

							$output .= '<label>';
							$output .= '<input type="checkbox" onclick="sm_disableunsubscribedtag();" class="sm_form_checkbox" name="tag' . $groups[ $j ]['Id'] . '" value="1"';
							if ( in_array( $groups[ $j ]['Id'], $user_current_tags ) ) {
								$output .= ' checked';
								$num_checked ++;
							}
							$output .= '/>';
							$output .= $groups[ $j ]['GroupName'] . '</label>';
						}
						$output .= '</div>';
					}
					$sm_default_tag_id = get_option( 'subscription_default_tag_id' );
					if ( $sm_default_tag_id != '' ) {
						$output .= <<<HTML
<input type="hidden" id="sm_unsubscribedtag" value="{($num_checked == 0) ? '1' : '0'}"
                                 name="tag{$sm_default_tag_id}" />
HTML;
					}
					$output .= <<<HTML
<input type="hidden" name="this_email" value="{$this_email}">
<input type="button" id="sm_unsubscribe_all_button" onclick="sm_unsubscribe_all()" value="Unsubscribe from All" />
<input type="submit" value="Save Preferences" />
</form>
</div>
HTML;
				}
			}
		}
		return $output;
	}

	public static function saveSubscriptionPreferences( $infusion_app ) {
		$this_email = null;
		if ( isset( $_POST['this_email'] ) ) {
			if ( filter_var( $_POST['this_email'], FILTER_VALIDATE_EMAIL ) ) {
				$this_email = sanitize_email( $_POST['this_email'] );
			}
		}
		$contact_return_fields = [ 'Id' ];
		$contact_id            = $infusion_app->findByEmail( $this_email, $contact_return_fields );
		$group_return_fields   = [ 'Id', 'GroupName' ];
		$group_query           = [ 'Id' => '%' ];
		$groups                = $infusion_app->dsQuery( 'ContactGroup', 1000, 0, $group_query, $group_return_fields );
		for ( $i = 0; $i < sizeof( $groups ); $i ++ ) {
			if ( isset( $_POST["tag{$groups[$i]['Id']}"] ) ) {
				if ( $_POST["tag{$groups[$i]['Id']}"] == '1' ) {
					$infusion_app->grpAssign( $contact_id[0]['Id'], $groups[ $i ]['Id'] );
				}
			} else {
				$infusion_app->grpRemove( $contact_id[0]['Id'], $groups[ $i ]['Id'] );
			}
		}
	}

	public
	static function pluginActivation() {

	}

	public
	static function pluginDeactivation() {

	}

	public
	static function checkSdk() {
		if ( get_option( 'emailtracking_isdk_app_name' ) == '' || get_option( 'emailtracking_isdk_api_key' ) == '' ) {
			return false;
		} else {
			return true;
		}
	}

	public
	static function sdkInit() {
		$appname = get_option( 'emailtracking_isdk_app_name' );
		$apikey  = get_option( 'emailtracking_isdk_api_key' );
		if ( isset( $_REQUEST['cid'] ) && isset( $_REQUEST['asid'] ) ) {
			$cid  = (int) $_REQUEST['cid'];
			$asid = (int) $_REQUEST['asid'];
		} else {
			return;
		}
		$app = new iSDK();
		$app->cfgCon( $appname, $apikey );
		$as = $app->runAS( $cid, $asid );
	}
}
