<?php

class SubscriptionManagementAdmin {
	public static function init() {
		add_action( 'admin_menu', array( 'SubscriptionManagementAdmin', 'adminMenu' ) );
	}

	public static function adminMenu() {
		add_options_page( 'InfusionSoft Subscription Management Settings', 'Subscription Mgmt', 'manage_options', 'subscription_management_settings', array(
			'SubscriptionManagementAdmin',
			'settingsPage'
		) );
	}

	public static function settingsPage() {
		self::saveOptions();
		?>
      <div class="pageparentdiv">
        <h2 class="hndle">
          <span>InfusionSoft Subscription Management Settings</span>
        </h2>
        <p<a href="https://webmissioncontrol.com/wp-content/uploads/2017/08/SubscriptionManagementforInfusionsoft.pdf"
             target="_blank">Read the full instructions</a></p>

        <div class="inside">
			<?php
			$appname = get_option( 'subscription_isdk_app_name' );
			$apikey  = get_option( 'subscription_isdk_api_key' );

			?>
          <form action="" method="post">
            <table class="form-table">
              <tr>
                <th scope="row">
                  <strong>iSDK App Name:</strong>
                </th>
                <td>
                  <input type="text" class="text" name="sm_appname"
                         value="<?php echo get_option( 'subscription_isdk_app_name' ); ?>">.infusionsoft.com
                  <br>
                  <span class="description">Your app name is the URL you use to access InfusionSoft.</span>
                </td>
              </tr>
              <tr>
                <th scope="row">
                  <strong>iSDK API Key:</strong>
                </th>
                <td>
                  <input type="text" class="text" size="45" name="sm_apikey"
                         value="<?php echo get_option( 'subscription_isdk_api_key' ); ?>">
                </td>
              </tr>
              <tr>
                <td>
                  <input class="button button-primary button-large" type="submit" value="Save">
                </td>
              </tr>
				<?php
				$app = new iSDK();
				if ( $appname && $apikey ) {
					if ( $app && $app->cfgCon( $appname, $apikey ) ) {
						echo '<div class="updated"><p>API Key Verified Working.</p></div>';
					}
				}
				if ( $appname && $apikey ) {
					if ( $app->cfgCon( $appname, $apikey ) ) {
						?>
                      <tr>
                        <th scope="row">
                          <strong>Tag Categories:</strong>
                        </th>
                        <td>
							<?php
							$current_tag_categories = explode( ',', get_option( 'subscription_tag_categories' ) );
							$category_return_fields = array( 'Id', 'CategoryName' );
							$category_query         = array( 'Id' => '%' );
							$categories             = $app->dsQuery( 'ContactGroupCategory', 1000, 0, $category_query, $category_return_fields );
							for ( $i = 0; $i < sizeof( $categories ); $i ++ ) {
								echo '<label><input type="checkbox" value="' . $categories[ $i ]['Id'] . '" name="checkedtagcats[]"';
								if ( is_array( $current_tag_categories ) && in_array( $categories[ $i ]['Id'], $current_tag_categories ) ) {
									echo ' checked';
								}
								echo '> ' . $categories[ $i ]['CategoryName'] . '<br>';
								$group_return_fields = array( 'Id', 'GroupName' );
								$group_query         = array( 'GroupCategoryId' => $categories[ $i ]['Id'] );
								$groups              = $app->dsQuery( 'ContactGroup', 1000, 0, $group_query, $group_return_fields );
								for ( $j = 0; $j < sizeof( $groups ); $j ++ ) {
									echo '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<small>' . $groups[ $j ]['Id'] . ': ' . $groups[ $j ]['GroupName'] . '</small>';
									echo '<br>';
								}
								echo '</label><br>';
							}
							?>
                          <br>
                          <span class="description">Select the tag categories you want to show on the subscription management page.</span>
                        </td>
                      </tr>
                      <tr>
                        <th scope="row">
                          <strong>Default Tag ID:</strong>
                        </th>
                        <td>
                          <input type="text" class="text" size="3" name="sm_unsubscribe_id"
                                 value="<?php echo get_option( 'subscription_default_tag_id' ); ?>">
                          <br>
                          <span class="description">If a user unsubscribes from all email lists, this is the default tag that will be attached to their account.<br>If left blank, no tags will be attached to their account in InfusionSoft.</span>
                        </td>
                      </tr>
						<?php
					}
				}
				?>
            </table>
            <p>
              <input class="button button-primary button-large" type="submit" value="Save">
            </p>

          </form>
        </div>
      </div>

	<?php }

	public static function saveOptions() {
		if ( ! isset( $_POST['sm_appname'] ) || ! isset( $_POST['sm_apikey'] ) ) {
			return;
		}
		if ( is_string( $_POST['sm_appname'] ) ) {
			$appname = trim( sanitize_text_field( $_POST['sm_appname'] ) );
		}
		if ( is_string( $_POST['sm_apikey'] ) ) {
			$apikey = trim( sanitize_text_field( $_POST['sm_apikey'] ) );
		}
		if ( is_numeric( $_POST['sm_unsubscribe_id'] ) ) {
			$tid = (int) trim( $_POST['sm_unsubscribe_id'] );
		}
		if ($_POST['checkedtagcats']) {
		  $checkedtags = $_POST['checkedtagcats'];
			$sanitizedArr = [];
		  $filteredArr = [];

			foreach( $checkedtags as $tag )
			{
				$sanitizedArr[] = ( filter_var( $tag, FILTER_SANITIZE_STRING ) );
			}

			foreach( $sanitizedArr as $tag )
	  {
		  $filteredArr[] = ( filter_var( $tag, FILTER_VALIDATE_INT ) );
	  }

			$categories = implode( ',', $filteredArr );
		}

		if ( $appname ) {
			update_option( 'subscription_isdk_app_name', $appname );
		}
		if ( $apikey ) {
			update_option( 'subscription_isdk_api_key', $apikey );
		}
		if ( $tid ) {
			update_option( 'subscription_default_tag_id', $tid );
		}
		if ( $categories ) {
			update_option( 'subscription_tag_categories', $categories );
		}
	}
}